@@ -121,15 +121,15 @@ class IntegrationTester:
             # This is a simplified implementation
             # In practice, you would map test case names to actual test functions
             result = self.run_test(
-                placeholder_test, test_case_name, [c.name for c in test_suite.components]
+                placeholder_test,
+                test_case_name,
+                [c.name for c in test_suite.components],
             )
             results.append(result)
 
         return results
 
-    def run_concurrent_tests(
-        self, tests: List[tuple], timeout: Optional[float] = None
-    ) -> List[IntegrationTestResult]:
+    def run_concurrent_tests(self, tests: List[tuple], timeout: Optional[float] = None) -> List[IntegrationTestResult]:
         """
         Run multiple tests concurrently.
 
@@ -173,9 +173,7 @@ class IntegrationTester:
         """
         return self.discovery.discover_components(base_path)
 
-    def create_test_environment(
-        self, temp_dir: Optional[str] = None
-    ) -> TestEnvironment:
+    def create_test_environment(self, temp_dir: Optional[str] = None) -> TestEnvironment:
         """
         Create a test environment for integration testing.
 
@@ -198,7 +196,7 @@ class IntegrationTester:
             Exported results
         """
         if format == "dict":
-            return [vars(result) for result in self.test_results]
+            return [vars(result) for result in self.test_results]  # type: ignore[return-value]
         elif format == "summary":
             return {
                 "stats": self.get_test_stats(),
