@@ -32,25 +32,28 @@ from .jit_enhanced_hook_manager import (
 
 class SchedulingStrategy(Enum):
     """Hook scheduling strategies"""
-    PRIORITY_FIRST = "priority_first"         # Execute highest priority hooks first
-    PERFORMANCE_FIRST = "performance_first"   # Execute fastest hooks first
-    PHASE_OPTIMIZED = "phase_optimized"       # Optimize for current phase
-    TOKEN_EFFICIENT = "token_efficient"       # Minimize token usage
-    BALANCED = "balanced"                     # Balance all factors
+
+    PRIORITY_FIRST = "priority_first"  # Execute highest priority hooks first
+    PERFORMANCE_FIRST = "performance_first"  # Execute fastest hooks first
+    PHASE_OPTIMIZED = "phase_optimized"  # Optimize for current phase
+    TOKEN_EFFICIENT = "token_efficient"  # Minimize token usage
+    BALANCED = "balanced"  # Balance all factors
 
 
 class SchedulingDecision(Enum):
     """Scheduling decisions for hooks"""
-    EXECUTE = "execute"                       # Execute hook now
-    DEFER = "defer"                           # Defer to later
-    SKIP = "skip"                             # Skip execution
-    PARALLEL = "parallel"                     # Execute in parallel group
-    SEQUENTIAL = "sequential"                 # Execute sequentially
+
+    EXECUTE = "execute"  # Execute hook now
+    DEFER = "defer"  # Defer to later
+    SKIP = "skip"  # Skip execution
+    PARALLEL = "parallel"  # Execute in parallel group
+    SEQUENTIAL = "sequential"  # Execute sequentially
 
 
 @dataclass
 class HookSchedulingContext:
     """Context for hook scheduling decisions"""
+
     event_type: HookEvent
     current_phase: Phase
     user_input: str
@@ -65,6 +68,7 @@ class HookSchedulingContext:
 @dataclass
 class ScheduledHook:
     """Hook scheduled for execution"""
+
     hook_path: str
     metadata: HookMetadata
     priority_score: float
@@ -81,6 +85,7 @@ class ScheduledHook:
 @dataclass
 class SchedulingResult:
     """Result of hook scheduling"""
+
     scheduled_hooks: List[ScheduledHook]
     execution_plan: List[List[ScheduledHook]]  # Groups of hooks to execute
     estimated_total_time_ms: float
@@ -93,6 +98,7 @@ class SchedulingResult:
 @dataclass
 class ExecutionGroup:
     """Group of hooks to execute together"""
+
     group_id: int
     execution_type: SchedulingDecision  # PARALLEL or SEQUENTIAL
     hooks: List[ScheduledHook]
@@ -119,7 +125,7 @@ class PhaseOptimizedHookScheduler:
         hook_manager: Optional[JITEnhancedHookManager] = None,
         default_strategy: SchedulingStrategy = SchedulingStrategy.PHASE_OPTIMIZED,
         max_parallel_groups: int = 3,
-        enable_adaptive_scheduling: bool = True
+        enable_adaptive_scheduling: bool = True,
     ):
         """Initialize Phase-Optimized Hook Scheduler
 
@@ -135,7 +141,7 @@ class PhaseOptimizedHookScheduler:
         self.enable_adaptive_scheduling = enable_adaptive_scheduling
 
         # Performance tracking
-        self._scheduling_history: List[SchedulingResult] = []
+        self._scheduling_history: List[Dict[str, Any]] = []
         self._performance_cache: Dict[str, Dict[str, float]] = {}
         self._scheduling_lock = threading.Lock()
 
@@ -144,12 +150,7 @@ class PhaseOptimizedHookScheduler:
 
         # Adaptive strategy selection
         self._strategy_performance: Dict[SchedulingStrategy, Dict[str, float]] = {
-            strategy: {
-                "success_rate": 1.0,
-                "avg_efficiency": 0.8,
-                "usage_count": 0
-            }
-            for strategy in SchedulingStrategy
+            strategy: {"success_rate": 1.0, "avg_efficiency": 0.8, "usage_count": 0} for strategy in SchedulingStrategy
         }
 
     def _initialize_phase_parameters(self) -> Dict[Phase, Dict[str, Any]]:
@@ -162,9 +163,9 @@ class PhaseOptimizedHookScheduler:
                     HookPriority.CRITICAL: 1.0,
                     HookPriority.HIGH: 0.9,
                     HookPriority.NORMAL: 0.6,
-                    HookPriority.LOW: 0.2
+                    HookPriority.LOW: 0.2,
                 },
-                "prefer_parallel": False  # Sequential for consistency
+                "prefer_parallel": False,  # Sequential for consistency
             },
             Phase.RED: {
                 "max_total_time_ms": 800.0,
@@ -173,9 +174,9 @@ class PhaseOptimizedHookScheduler:
                     HookPriority.CRITICAL: 1.0,
                     HookPriority.HIGH: 1.0,  # Testing is high priority
                     HookPriority.NORMAL: 0.8,
-                    HookPriority.LOW: 0.3
+                    HookPriority.LOW: 0.3,
                 },
-                "prefer_parallel": True  # Parallel for faster test feedback
+                "prefer_parallel": True,  # Parallel for faster test feedback
             },
             Phase.GREEN: {
                 "max_total_time_ms": 600.0,
@@ -184,9 +185,9 @@ class PhaseOptimizedHookScheduler:
                     HookPriority.CRITICAL: 1.0,
                     HookPriority.HIGH: 0.8,
                     HookPriority.NORMAL: 0.7,
-                    HookPriority.LOW: 0.4
+                    HookPriority.LOW: 0.4,
                 },
-                "prefer_parallel": True  # Parallel for faster implementation
+                "prefer_parallel": True,  # Parallel for faster implementation
             },
             Phase.REFACTOR: {
                 "max_total_time_ms": 1200.0,
@@ -195,9 +196,9 @@ class PhaseOptimizedHookScheduler:
                     HookPriority.CRITICAL: 1.0,
                     HookPriority.HIGH: 0.9,  # Code quality is important
                     HookPriority.NORMAL: 0.8,
-                    HookPriority.LOW: 0.5
+                    HookPriority.LOW: 0.5,
                 },
-                "prefer_parallel": False  # Sequential for safety
+                "prefer_parallel": False,  # Sequential for safety
             },
             Phase.SYNC: {
                 "max_total_time_ms": 1500.0,
@@ -206,9 +207,9 @@ class PhaseOptimizedHookScheduler:
                     HookPriority.CRITICAL: 1.0,
                     HookPriority.HIGH: 0.7,
                     HookPriority.NORMAL: 0.9,  # Documentation is important
-                    HookPriority.LOW: 0.6
+                    HookPriority.LOW: 0.6,
                 },
-                "prefer_parallel": False  # Sequential for consistency
+                "prefer_parallel": False,  # Sequential for consistency
             },
             Phase.DEBUG: {
                 "max_total_time_ms": 500.0,
@@ -217,9 +218,9 @@ class PhaseOptimizedHookScheduler:
                     HookPriority.CRITICAL: 1.0,
                     HookPriority.HIGH: 0.9,  # Debug info is critical
                     HookPriority.NORMAL: 0.8,
-                    HookPriority.LOW: 0.3
+                    HookPriority.LOW: 0.3,
                 },
-                "prefer_parallel": True  # Parallel for faster debugging
+                "prefer_parallel": True,  # Parallel for faster debugging
             },
             Phase.PLANNING: {
                 "max_total_time_ms": 800.0,
@@ -228,17 +229,17 @@ class PhaseOptimizedHookScheduler:
                     HookPriority.CRITICAL: 1.0,
                     HookPriority.HIGH: 0.8,
                     HookPriority.NORMAL: 0.7,
-                    HookPriority.LOW: 0.4
+                    HookPriority.LOW: 0.4,
                 },
-                "prefer_parallel": False  # Sequential for careful planning
-            }
+                "prefer_parallel": False,  # Sequential for careful planning
+            },
         }
 
     async def schedule_hooks(
         self,
         event_type: HookEvent,
         context: HookSchedulingContext,
-        strategy: Optional[SchedulingStrategy] = None
+        strategy: Optional[SchedulingStrategy] = None,
     ) -> SchedulingResult:
         """Schedule hooks for execution with optimization
 
@@ -259,9 +260,7 @@ class PhaseOptimizedHookScheduler:
         available_hooks = self.hook_manager._hooks_by_event.get(event_type, [])
 
         # Create scheduled hooks with initial analysis
-        scheduled_hooks = await self._create_scheduled_hooks(
-            available_hooks, context, selected_strategy
-        )
+        scheduled_hooks = await self._create_scheduled_hooks(available_hooks, context, selected_strategy)
 
         # Filter and prioritize hooks
         filtered_hooks = self._filter_hooks_by_constraints(scheduled_hooks, context)
@@ -271,9 +270,7 @@ class PhaseOptimizedHookScheduler:
         dependency_resolved_hooks = self._resolve_dependencies(prioritized_hooks)
 
         # Create execution groups
-        execution_groups = self._create_execution_groups(
-            dependency_resolved_hooks, context, selected_strategy
-        )
+        execution_groups = self._create_execution_groups(dependency_resolved_hooks, context, selected_strategy)
 
         # Optimize execution order
         optimized_groups = self._optimize_execution_order(execution_groups, context)
@@ -290,10 +287,16 @@ class PhaseOptimizedHookScheduler:
 
         # Separate skipped and deferred hooks
         executed_hooks = [hook for group in optimized_groups for hook in group.hooks]
-        skipped_hooks = [hook for hook in scheduled_hooks if hook not in executed_hooks and
-                        hook.scheduling_decision == SchedulingDecision.SKIP]
-        deferred_hooks = [hook for hook in scheduled_hooks if hook not in executed_hooks and
-                         hook.scheduling_decision == SchedulingDecision.DEFER]
+        skipped_hooks = [
+            hook
+            for hook in scheduled_hooks
+            if hook not in executed_hooks and hook.scheduling_decision == SchedulingDecision.SKIP
+        ]
+        deferred_hooks = [
+            hook
+            for hook in scheduled_hooks
+            if hook not in executed_hooks and hook.scheduling_decision == SchedulingDecision.DEFER
+        ]
 
         # Create scheduling result
         result = SchedulingResult(
@@ -303,7 +306,7 @@ class PhaseOptimizedHookScheduler:
             estimated_total_tokens=total_tokens,
             skipped_hooks=skipped_hooks,
             deferred_hooks=deferred_hooks,
-            scheduling_strategy=selected_strategy
+            scheduling_strategy=selected_strategy,
         )
 
         # Update scheduling history and performance
@@ -312,11 +315,7 @@ class PhaseOptimizedHookScheduler:
 
         return result
 
-    def _select_optimal_strategy(
-        self,
-        event_type: HookEvent,
-        context: HookSchedulingContext
-    ) -> SchedulingStrategy:
+    def _select_optimal_strategy(self, event_type: HookEvent, context: HookSchedulingContext) -> SchedulingStrategy:
         """Select optimal scheduling strategy based on context"""
         if not self.enable_adaptive_scheduling:
             return self.default_strategy
@@ -345,7 +344,7 @@ class PhaseOptimizedHookScheduler:
 
             for strategy, performance in self._strategy_performance.items():
                 if performance["usage_count"] > 0:
-                    efficiency = (performance["success_rate"] * performance["avg_efficiency"])
+                    efficiency = performance["success_rate"] * performance["avg_efficiency"]
                     if efficiency > best_efficiency:
                         best_efficiency = efficiency
                         best_strategy = strategy
@@ -356,7 +355,7 @@ class PhaseOptimizedHookScheduler:
         self,
         hook_paths: List[str],
         context: HookSchedulingContext,
-        strategy: SchedulingStrategy
+        strategy: SchedulingStrategy,
     ) -> List[ScheduledHook]:
         """Create scheduled hooks from hook paths with analysis"""
         scheduled_hooks = []
@@ -367,9 +366,7 @@ class PhaseOptimizedHookScheduler:
                 continue
 
             # Calculate priority score based on strategy
-            priority_score = self._calculate_priority_score(
-                metadata, context, strategy
-            )
+            priority_score = self._calculate_priority_score(metadata, context, strategy)
 
             # Estimate execution cost
             estimated_cost = self._estimate_hook_cost(metadata, context)
@@ -388,7 +385,7 @@ class PhaseOptimizedHookScheduler:
                 estimated_time_ms=estimated_time,
                 scheduling_decision=scheduling_decision,
                 dependencies=metadata.dependencies.copy(),
-                dependents=set()
+                dependents=set(),
             )
 
             scheduled_hooks.append(scheduled_hook)
@@ -399,7 +396,7 @@ class PhaseOptimizedHookScheduler:
         self,
         metadata: HookMetadata,
         context: HookSchedulingContext,
-        strategy: SchedulingStrategy
+        strategy: SchedulingStrategy,
     ) -> float:
         """Calculate priority score for hook based on strategy"""
         base_score = 0.0
@@ -441,11 +438,7 @@ class PhaseOptimizedHookScheduler:
 
         return base_score
 
-    def _estimate_hook_cost(
-        self,
-        metadata: HookMetadata,
-        context: HookSchedulingContext
-    ) -> int:
+    def _estimate_hook_cost(self, metadata: HookMetadata, context: HookSchedulingContext) -> int:
         """Estimate token cost for hook execution"""
         base_cost = metadata.token_cost_estimate
 
@@ -464,11 +457,7 @@ class PhaseOptimizedHookScheduler:
 
         return base_cost
 
-    def _estimate_hook_time(
-        self,
-        metadata: HookMetadata,
-        context: HookSchedulingContext
-    ) -> float:
+    def _estimate_hook_time(self, metadata: HookMetadata, context: HookSchedulingContext) -> float:
         """Estimate execution time for hook"""
         base_time = metadata.estimated_execution_time_ms
 
@@ -485,7 +474,7 @@ class PhaseOptimizedHookScheduler:
         metadata: HookMetadata,
         context: HookSchedulingContext,
         estimated_cost: int,
-        estimated_time: float
+        estimated_time: float,
     ) -> SchedulingDecision:
         """Make initial scheduling decision for hook"""
         # Critical hooks always execute
@@ -516,9 +505,7 @@ class PhaseOptimizedHookScheduler:
         return SchedulingDecision.EXECUTE
 
     def _filter_hooks_by_constraints(
-        self,
-        scheduled_hooks: List[ScheduledHook],
-        context: HookSchedulingContext
+        self, scheduled_hooks: List[ScheduledHook], context: HookSchedulingContext
     ) -> List[ScheduledHook]:
         """Filter hooks based on constraints"""
         filtered_hooks = []
@@ -534,8 +521,7 @@ class PhaseOptimizedHookScheduler:
                 continue
 
             # Check if hook fits within constraints
-            if hook.estimated_cost <= remaining_token_budget and \
-               hook.estimated_time_ms <= remaining_time_budget:
+            if hook.estimated_cost <= remaining_token_budget and hook.estimated_time_ms <= remaining_time_budget:
                 filtered_hooks.append(hook)
                 remaining_token_budget -= hook.estimated_cost
                 remaining_time_budget -= hook.estimated_time_ms
@@ -550,7 +536,7 @@ class PhaseOptimizedHookScheduler:
         self,
         scheduled_hooks: List[ScheduledHook],
         context: HookSchedulingContext,
-        strategy: SchedulingStrategy
+        strategy: SchedulingStrategy,
     ) -> List[ScheduledHook]:
         """Prioritize hooks for execution"""
         # Separate by scheduling decision
@@ -583,7 +569,8 @@ class PhaseOptimizedHookScheduler:
         while remaining_hooks:
             # Find hooks with no unresolved dependencies
             ready_hooks = [
-                h for h in remaining_hooks
+                h
+                for h in remaining_hooks
                 if not any(dep in [rh.hook_path for rh in remaining_hooks] for dep in h.dependencies)
             ]
 
@@ -603,7 +590,7 @@ class PhaseOptimizedHookScheduler:
         self,
         hooks: List[ScheduledHook],
         context: HookSchedulingContext,
-        strategy: SchedulingStrategy
+        strategy: SchedulingStrategy,
     ) -> List[ExecutionGroup]:
         """Create execution groups for optimal performance"""
         groups = []
@@ -619,13 +606,18 @@ class PhaseOptimizedHookScheduler:
                 continue
 
             # Determine execution type
-            execution_type = SchedulingDecision.PARALLEL if (prefer_parallel and hook.metadata.parallel_safe) else SchedulingDecision.SEQUENTIAL
+            execution_type = (
+                SchedulingDecision.PARALLEL
+                if (prefer_parallel and hook.metadata.parallel_safe)
+                else SchedulingDecision.SEQUENTIAL
+            )
 
             # Create new group if needed
-            if (current_group is None or
-                current_group.execution_type != execution_type or
-                len(current_group.hooks) >= self.max_parallel_groups):
-
+            if (
+                current_group is None
+                or current_group.execution_type != execution_type
+                or len(current_group.hooks) >= self.max_parallel_groups
+            ):
                 current_group = ExecutionGroup(
                     group_id=group_id,
                     execution_type=execution_type,
@@ -633,7 +625,7 @@ class PhaseOptimizedHookScheduler:
                     estimated_time_ms=0.0,
                     estimated_tokens=0,
                     max_wait_time_ms=0.0,
-                    dependencies=set()
+                    dependencies=set(),
                 )
                 groups.append(current_group)
                 group_id += 1
@@ -656,9 +648,7 @@ class PhaseOptimizedHookScheduler:
         return groups
 
     def _optimize_execution_order(
-        self,
-        groups: List[ExecutionGroup],
-        context: HookSchedulingContext
+        self, groups: List[ExecutionGroup], context: HookSchedulingContext
     ) -> List[ExecutionGroup]:
         """Optimize execution order of groups"""
         if len(groups) <= 1:
@@ -685,7 +675,7 @@ class PhaseOptimizedHookScheduler:
     def _update_scheduling_history(self, result: SchedulingResult, planning_time_ms: float) -> None:
         """Update scheduling history for learning"""
         with self._scheduling_lock:
-            history_entry = {
+            history_entry: Dict[str, Any] = {
                 "timestamp": datetime.now().isoformat(),
                 "strategy": result.scheduling_strategy.value,
                 "planning_time_ms": planning_time_ms,
@@ -694,7 +684,7 @@ class PhaseOptimizedHookScheduler:
                 "skipped_hooks": len(result.skipped_hooks),
                 "deferred_hooks": len(result.deferred_hooks),
                 "estimated_time_ms": result.estimated_total_time_ms,
-                "estimated_tokens": result.estimated_total_tokens
+                "estimated_tokens": result.estimated_total_tokens,
             }
 
             self._scheduling_history.append(history_entry)
@@ -707,7 +697,7 @@ class PhaseOptimizedHookScheduler:
         self,
         strategy: SchedulingStrategy,
         result: SchedulingResult,
-        context: HookSchedulingContext
+        context: HookSchedulingContext,
     ) -> None:
         """Update strategy performance metrics"""
         performance = self._strategy_performance[strategy]
@@ -724,7 +714,10 @@ class PhaseOptimizedHookScheduler:
 
             # Consider resource utilization
             time_efficiency = min(1.0, result.estimated_total_time_ms / context.max_execution_time_ms)
-            token_efficiency = min(1.0, result.estimated_total_tokens / max(1, context.available_token_budget))
+            token_efficiency = min(
+                1.0,
+                result.estimated_total_tokens / max(1, context.available_token_budget),
+            )
 
             # Overall efficiency
             overall_efficiency = (execution_ratio * 0.5) + (time_efficiency * 0.3) + (token_efficiency * 0.2)
@@ -746,7 +739,7 @@ class PhaseOptimizedHookScheduler:
                 return {
                     "total_schedules": 0,
                     "strategy_performance": {},
-                    "recent_performance": []
+                    "recent_performance": [],
                 }
 
             # Calculate strategy statistics
@@ -757,7 +750,7 @@ class PhaseOptimizedHookScheduler:
                         "usage_count": performance["usage_count"],
                         "success_rate": performance["success_rate"],
                         "avg_efficiency": performance["avg_efficiency"],
-                        "recommendation_score": performance["success_rate"] * performance["avg_efficiency"]
+                        "recommendation_score": performance["success_rate"] * performance["avg_efficiency"],
                     }
 
             # Get recent performance
@@ -767,8 +760,14 @@ class PhaseOptimizedHookScheduler:
                 "total_schedules": total_schedules,
                 "strategy_performance": strategy_stats,
                 "recent_performance": recent_performance,
-                "recommended_strategy": max(strategy_stats.keys(),
-                                          key=lambda k: strategy_stats[k]["recommendation_score"]) if strategy_stats else None
+                "recommended_strategy": (
+                    max(
+                        strategy_stats.keys(),
+                        key=lambda k: strategy_stats[k]["recommendation_score"],
+                    )
+                    if strategy_stats
+                    else None
+                ),
             }
 
     def get_phase_optimization_insights(self, phase: Phase) -> Dict[str, Any]:
@@ -777,75 +776,62 @@ class PhaseOptimizedHookScheduler:
 
         # Analyze historical performance for this phase
         phase_schedules = [
-            s for s in self._scheduling_history
+            s
+            for s in self._scheduling_history
             if any(phase.value.lower() in s.get("context", "").lower() for phase in [phase])
         ]
 
-        insights = {
+        insights: Dict[str, Any] = {
             "phase": phase.value,
             "parameters": phase_params,
             "historical_schedules": len(phase_schedules),
-            "optimization_recommendations": []
+            "optimization_recommendations": [],
         }
 
         # Generate recommendations based on phase parameters
         if phase_params.get("prefer_parallel", False):
-            insights["optimization_recommendations"].append(
-                "This phase benefits from parallel hook execution"
-            )
+            recs_list = insights["optimization_recommendations"]
+            if isinstance(recs_list, list):
+                recs_list.append("This phase benefits from parallel hook execution")
         else:
-            insights["optimization_recommendations"].append(
-                "This phase prefers sequential hook execution for consistency"
-            )
+            recs_list = insights["optimization_recommendations"]
+            if isinstance(recs_list, list):
+                recs_list.append("This phase prefers sequential hook execution for consistency")
 
         if phase_params.get("token_budget_ratio", 0) > 0.2:
-            insights["optimization_recommendations"].append(
-                "This phase requires significant token budget - consider token-efficient scheduling"
-            )
+            recs_list = insights["optimization_recommendations"]
+            if isinstance(recs_list, list):
+                recs_list.append("This phase requires significant token budget - consider token-efficient scheduling")
 
         # Add strategy recommendations
         strategy_stats = self.get_scheduling_statistics()["strategy_performance"]
         best_strategy = (
-            max(
-                strategy_stats.items(),
-                key=lambda x: x[1]["recommendation_score"]
-            ) if strategy_stats else None
+            max(strategy_stats.items(), key=lambda x: x[1]["recommendation_score"]) if strategy_stats else None
         )
 
         if best_strategy:
             insights["recommended_strategy"] = best_strategy[0]
-            insights["strategy_rationale"] = (
-                f"Best performance with {best_strategy[0]} strategy (score: {best_strategy[1]['recommendation_score']:.2f})"
-            )
+            score = best_strategy[1]["recommendation_score"]
+            insights["strategy_rationale"] = f"Best performance with {best_strategy[0]} strategy (score: {score:.2f})"
 
         return insights
 
 
 # Convenience functions for common scheduling operations
 async def schedule_session_start_hooks(
-    context: HookSchedulingContext,
-    strategy: Optional[SchedulingStrategy] = None
+    context: HookSchedulingContext, strategy: Optional[SchedulingStrategy] = None
 ) -> SchedulingResult:
     """Schedule SessionStart hooks with phase optimization"""
     scheduler = PhaseOptimizedHookScheduler()
-    return await scheduler.schedule_hooks(
-        HookEvent.SESSION_START,
-        context,
-        strategy
-    )
+    return await scheduler.schedule_hooks(HookEvent.SESSION_START, context, strategy)
 
 
 async def schedule_pre_tool_hooks(
-    context: HookSchedulingContext,
-    strategy: Optional[SchedulingStrategy] = None
+    context: HookSchedulingContext, strategy: Optional[SchedulingStrategy] = None
 ) -> SchedulingResult:
     """Schedule PreToolUse hooks with phase optimization"""
     scheduler = PhaseOptimizedHookScheduler()
-    return await scheduler.schedule_hooks(
-        HookEvent.PRE_TOOL_USE,
-        context,
-        strategy
-    )
+    return await scheduler.schedule_hooks(HookEvent.PRE_TOOL_USE, context, strategy)
 
 
 def get_hook_scheduling_insights(phase: Phase) -> Dict[str, Any]:
@@ -865,7 +851,7 @@ if __name__ == "__main__":
             current_phase=Phase.SPEC,
             user_input="Creating new specification for user authentication",
             available_token_budget=10000,
-            max_execution_time_ms=1000.0
+            max_execution_time_ms=1000.0,
         )
 
         # Schedule hooks
