@@ -109,24 +109,12 @@ class PhaseExecutor:
 
             # Enhanced version context with multiple format options
             version_context["MOAI_VERSION"] = moai_version
-            version_context["MOAI_VERSION_SHORT"] = self._format_short_version(
-                moai_version
-            )
-            version_context["MOAI_VERSION_DISPLAY"] = self._format_display_version(
-                moai_version
-            )
-            version_context["MOAI_VERSION_TRIMMED"] = self._format_trimmed_version(
-                moai_version, max_length=10
-            )
-            version_context["MOAI_VERSION_SEMVER"] = self._format_semver_version(
-                moai_version
-            )
-            version_context["MOAI_VERSION_VALID"] = (
-                "true" if moai_version != "unknown" else "false"
-            )
-            version_context["MOAI_VERSION_SOURCE"] = self._get_version_source(
-                version_reader
-            )
+            version_context["MOAI_VERSION_SHORT"] = self._format_short_version(moai_version)
+            version_context["MOAI_VERSION_DISPLAY"] = self._format_display_version(moai_version)
+            version_context["MOAI_VERSION_TRIMMED"] = self._format_trimmed_version(moai_version, max_length=10)
+            version_context["MOAI_VERSION_SEMVER"] = self._format_semver_version(moai_version)
+            version_context["MOAI_VERSION_VALID"] = "true" if moai_version != "unknown" else "false"
+            version_context["MOAI_VERSION_SOURCE"] = self._get_version_source(version_reader)
 
             # Add performance metrics for debugging
             cache_age = version_reader.get_cache_age_seconds()
@@ -140,18 +128,10 @@ class PhaseExecutor:
             # Use fallback version with comprehensive fallback formatting
             fallback_version = __version__
             version_context["MOAI_VERSION"] = fallback_version
-            version_context["MOAI_VERSION_SHORT"] = self._format_short_version(
-                fallback_version
-            )
-            version_context["MOAI_VERSION_DISPLAY"] = self._format_display_version(
-                fallback_version
-            )
-            version_context["MOAI_VERSION_TRIMMED"] = self._format_trimmed_version(
-                fallback_version, max_length=10
-            )
-            version_context["MOAI_VERSION_SEMVER"] = self._format_semver_version(
-                fallback_version
-            )
+            version_context["MOAI_VERSION_SHORT"] = self._format_short_version(fallback_version)
+            version_context["MOAI_VERSION_DISPLAY"] = self._format_display_version(fallback_version)
+            version_context["MOAI_VERSION_TRIMMED"] = self._format_trimmed_version(fallback_version, max_length=10)
+            version_context["MOAI_VERSION_SEMVER"] = self._format_semver_version(fallback_version)
             version_context["MOAI_VERSION_VALID"] = "true"
             version_context["MOAI_VERSION_SOURCE"] = "fallback_package"
             version_context["MOAI_VERSION_CACHE_AGE"] = "unavailable"
@@ -292,9 +272,7 @@ class PhaseExecutor:
             progress_callback: Optional progress callback.
         """
         self.current_phase = 2
-        self._report_progress(
-            "Phase 2: Creating directory structure...", progress_callback
-        )
+        self._report_progress("Phase 2: Creating directory structure...", progress_callback)
 
         for directory in self.REQUIRED_DIRECTORIES:
             dir_path = project_path / directory
@@ -331,11 +309,7 @@ class PhaseExecutor:
                 language_config = {}
 
             # Detect OS for cross-platform Hook path configuration
-            hook_project_dir = (
-                "%CLAUDE_PROJECT_DIR%"
-                if platform.system() == "Windows"
-                else "$CLAUDE_PROJECT_DIR"
-            )
+            hook_project_dir = "%CLAUDE_PROJECT_DIR%" if platform.system() == "Windows" else "$CLAUDE_PROJECT_DIR"
 
             # Get enhanced version context with fallback strategies
             version_context = self._get_enhanced_version_context()
@@ -349,20 +323,14 @@ class PhaseExecutor:
                 "PROJECT_VERSION": config.get("version", "0.1.0"),
                 "PROJECT_OWNER": config.get("author", "@user"),
                 "AUTHOR": config.get("author", "@user"),
-                "CONVERSATION_LANGUAGE": language_config.get(
-                    "conversation_language", "en"
-                ),
-                "CONVERSATION_LANGUAGE_NAME": language_config.get(
-                    "conversation_language_name", "English"
-                ),
+                "CONVERSATION_LANGUAGE": language_config.get("conversation_language", "en"),
+                "CONVERSATION_LANGUAGE_NAME": language_config.get("conversation_language_name", "English"),
                 "CODEBASE_LANGUAGE": config.get("language", "generic"),
                 "PROJECT_DIR": hook_project_dir,
             }
             processor.set_context(context)
 
-        processor.copy_templates(
-            backup=False, silent=True
-        )  # Avoid progress bar conflicts
+        processor.copy_templates(backup=False, silent=True)  # Avoid progress bar conflicts
 
         # Post-process: Set executable permission on shell scripts
         # This is necessary because git may not preserve file permissions during clone/checkout
@@ -408,9 +376,7 @@ class PhaseExecutor:
             List of created files.
         """
         self.current_phase = 4
-        self._report_progress(
-            "Phase 4: Generating configurations...", progress_callback
-        )
+        self._report_progress("Phase 4: Generating configurations...", progress_callback)
 
         logger = logging.getLogger(__name__)
 
@@ -427,9 +393,7 @@ class PhaseExecutor:
                 existing_config = {}
 
         # Enhanced config merging with comprehensive version preservation
-        merged_config = self._merge_configuration_preserving_versions(
-            config, existing_config
-        )
+        merged_config = self._merge_configuration_preserving_versions(config, existing_config)
 
         # Enhanced version handling using VersionReader for consistency
         try:
@@ -437,17 +401,11 @@ class PhaseExecutor:
             current_config_version = version_reader.get_version()
 
             # Ensure version consistency across the merged config
-            self._ensure_version_consistency(
-                merged_config, current_config_version, existing_config
-            )
+            self._ensure_version_consistency(merged_config, current_config_version, existing_config)
 
-            logger.debug(
-                f"Version consistency check completed. Current version: {current_config_version}"
-            )
+            logger.debug(f"Version consistency check completed. Current version: {current_config_version}")
         except Exception as e:
-            logger.warning(
-                f"Version consistency check failed: {e}. Using fallback version."
-            )
+            logger.warning(f"Version consistency check failed: {e}. Using fallback version.")
             merged_config["moai"]["version"] = __version__
 
         # Write final config with enhanced formatting
@@ -487,9 +445,7 @@ class PhaseExecutor:
         for section_name, strategy in config_sections.items():
             if section_name in existing_config:
                 logger.debug(f"Merging section: {section_name}")
-                self._merge_config_section(
-                    merged_config, existing_config, section_name, strategy
-                )
+                self._merge_config_section(merged_config, existing_config, section_name, strategy)
 
         return merged_config
 
@@ -573,12 +529,8 @@ class PhaseExecutor:
         elif "version" in config_moai:
             # Version already in new config, validate it
             config_version = config_moai["version"]
-            if config_version == "unknown" or not self._is_valid_version_format(
-                config_version
-            ):
-                logger.debug(
-                    f"Invalid config version {config_version}, updating to current: {current_version}"
-                )
+            if config_version == "unknown" or not self._is_valid_version_format(config_version):
+                logger.debug(f"Invalid config version {config_version}, updating to current: {current_version}")
                 config_moai["version"] = current_version
         else:
             # No version found, use current version
@@ -600,9 +552,7 @@ class PhaseExecutor:
         pattern = r"^v?(\d+\.\d+\.\d+(-[a-zA-Z0-9]+)?)$"
         return bool(re.match(pattern, version))
 
-    def _write_configuration_file(
-        self, config_path: Path, config: dict[str, Any]
-    ) -> None:
+    def _write_configuration_file(self, config_path: Path, config: dict[str, Any]) -> None:
         """
         Write configuration file with enhanced formatting and error handling.
 
@@ -641,9 +591,7 @@ class PhaseExecutor:
             progress_callback: Optional progress callback.
         """
         self.current_phase = 5
-        self._report_progress(
-            "Phase 5: Validation and finalization...", progress_callback
-        )
+        self._report_progress("Phase 5: Validation and finalization...", progress_callback)
 
         # Validate installation results
         # Comprehensive installation validation
@@ -651,9 +599,8 @@ class PhaseExecutor:
         # - 0-project.md, 1-plan.md, 2-run.md, 3-sync.md
         self.validator.validate_installation(project_path)
 
-        # Initialize Git for team mode
-        if mode == "team":
-            self._initialize_git(project_path)
+        # Initialize Git for all modes (team, personal, solo)
+        self._initialize_git(project_path)
 
     def _create_backup(self, project_path: Path) -> None:
         """Create a single backup (v0.4.2).
@@ -718,11 +665,17 @@ class PhaseExecutor:
                 dst_item.mkdir(parents=True, exist_ok=True)
 
     def _initialize_git(self, project_path: Path) -> None:
-        """Initialize a Git repository.
+        """Initialize a Git repository if not already initialized.
 
         Args:
             project_path: Project path.
         """
+        # Check if .git directory already exists
+        git_dir = project_path / ".git"
+        if git_dir.exists() and git_dir.is_dir():
+            # Git already initialized, skip
+            return
+
         try:
             subprocess.run(
                 ["git", "init"],
