@@ -53,9 +53,7 @@ class TemplateMerger:
         # Merge when project info exists
         if project_info:
             # Remove the project info section from the template
-            template_project_start, _ = self._find_project_info_section(
-                template_content
-            )
+            template_project_start, _ = self._find_project_info_section(template_content)
             if template_project_start != -1:
                 template_content = template_content[:template_project_start].rstrip()
 
@@ -90,9 +88,7 @@ class TemplateMerger:
         existing_lines = existing_path.read_text(encoding="utf-8").splitlines()
 
         # Merge while removing duplicates
-        merged_lines = existing_lines + [
-            line for line in template_lines if line not in existing_lines
-        ]
+        merged_lines = existing_lines + [line for line in template_lines if line not in existing_lines]
 
         existing_path.write_text("\n".join(merged_lines) + "\n", encoding="utf-8")
 
@@ -127,9 +123,7 @@ class TemplateMerger:
 
         return new_config
 
-    def merge_settings_json(
-        self, template_path: Path, existing_path: Path, backup_path: Path | None = None
-    ) -> None:
+    def merge_settings_json(self, template_path: Path, existing_path: Path, backup_path: Path | None = None) -> None:
         """Smart merge for .claude/settings.json.
 
         Rules:
@@ -175,9 +169,7 @@ class TemplateMerger:
         # Override with merged values
         merged["env"] = merged_env
         merged["permissions"] = {
-            "defaultMode": template_data.get("permissions", {}).get(
-                "defaultMode", "default"
-            ),
+            "defaultMode": template_data.get("permissions", {}).get("defaultMode", "default"),
             "allow": merged_allow,
             "ask": merged_ask,
             "deny": merged_deny,
@@ -189,9 +181,7 @@ class TemplateMerger:
             if field in user_data:
                 merged[field] = user_data[field]
 
-        existing_path.write_text(
-            json.dumps(merged, indent=2, ensure_ascii=False) + "\n", encoding="utf-8"
-        )
+        existing_path.write_text(json.dumps(merged, indent=2, ensure_ascii=False) + "\n", encoding="utf-8")
 
     def merge_github_workflows(self, template_dir: Path, existing_dir: Path) -> None:
         """Smart merge for .github/workflows/ directory.
@@ -224,9 +214,7 @@ class TemplateMerger:
                 dst_item = existing_dir / rel_path
 
                 # Handle workflow files specially
-                if rel_path.parent.name == "workflows" and rel_path.name.endswith(
-                    ".yml"
-                ):
+                if rel_path.parent.name == "workflows" and rel_path.name.endswith(".yml"):
                     # Only update MoAI-ADK managed workflows (moai-*.yml)
                     if rel_path.name.startswith("moai-"):
                         dst_item.parent.mkdir(parents=True, exist_ok=True)
