@@ -62,23 +62,13 @@ class TemplateProcessorConfig:
         return cls(
             version_cache_ttl_seconds=config_dict.get("version_cache_ttl_seconds", 120),
             version_fallback=config_dict.get("version_fallback", "unknown"),
-            version_format_regex=config_dict.get(
-                "version_format_regex", r"^v?(\d+\.\d+\.\d+(-[a-zA-Z0-9]+)?)$"
-            ),
-            enable_version_validation=config_dict.get(
-                "enable_version_validation", True
-            ),
+            version_format_regex=config_dict.get("version_format_regex", r"^v?(\d+\.\d+\.\d+(-[a-zA-Z0-9]+)?)$"),
+            enable_version_validation=config_dict.get("enable_version_validation", True),
             preserve_user_version=config_dict.get("preserve_user_version", True),
-            validate_template_variables=config_dict.get(
-                "validate_template_variables", True
-            ),
+            validate_template_variables=config_dict.get("validate_template_variables", True),
             max_variable_length=config_dict.get("max_variable_length", 50),
-            allowed_variable_pattern=config_dict.get(
-                "allowed_variable_pattern", r"^[A-Z_]+$"
-            ),
-            enable_substitution_warnings=config_dict.get(
-                "enable_substitution_warnings", True
-            ),
+            allowed_variable_pattern=config_dict.get("allowed_variable_pattern", r"^[A-Z_]+$"),
+            enable_substitution_warnings=config_dict.get("enable_substitution_warnings", True),
             enable_caching=config_dict.get("enable_caching", True),
             cache_size=config_dict.get("cache_size", 100),
             async_operations=config_dict.get("async_operations", False),
@@ -96,7 +86,7 @@ class TemplateProcessor:
         ".moai/reports/",  # User reports
         ".moai/project/",  # User project documents (product/structure/tech.md)
         # config.json is now FORCE OVERWRITTEN (backup in .moai-backups/)
-        # Merge via /alfred:0-project when optimized=false
+        # Merge via /moai:0-project when optimized=false
     ]
 
     # Paths excluded from backups
@@ -104,10 +94,10 @@ class TemplateProcessor:
 
     # Common template variables with validation hints
     COMMON_TEMPLATE_VARIABLES = {
-        "PROJECT_DIR": "Cross-platform project path (run /alfred:0-project to set)",
-        "PROJECT_NAME": "Project name (run /alfred:0-project to set)",
-        "AUTHOR": "Project author (run /alfred:0-project to set)",
-        "CONVERSATION_LANGUAGE": "Interface language (run /alfred:0-project to set)",
+        "PROJECT_DIR": "Cross-platform project path (run /moai:0-project to set)",
+        "PROJECT_NAME": "Project name (run /moai:0-project to set)",
+        "AUTHOR": "Project author (run /moai:0-project to set)",
+        "CONVERSATION_LANGUAGE": "Interface language (run /moai:0-project to set)",
         "MOAI_VERSION": "MoAI-ADK version (should be set automatically)",
         "MOAI_VERSION_SHORT": "Short MoAI-ADK version (without 'v' prefix)",
         "MOAI_VERSION_DISPLAY": "Display version with proper formatting",
@@ -119,9 +109,7 @@ class TemplateProcessor:
         "CREATION_TIMESTAMP": "Project creation timestamp",
     }
 
-    def __init__(
-        self, target_path: Path, config: Optional[TemplateProcessorConfig] = None
-    ) -> None:
+    def __init__(self, target_path: Path, config: Optional[TemplateProcessorConfig] = None) -> None:
         """Initialize the processor with enhanced configuration.
 
         Args:
@@ -135,16 +123,14 @@ class TemplateProcessor:
         self.context: dict[str, str] = {}  # Template variable substitution context
         self._version_reader: VersionReader | None = None
         self.config = config or TemplateProcessorConfig()
-        self._substitution_cache: Dict[str, str] = {}  # Cache for substitution results
-        self._variable_validation_cache: Dict[str, bool] = (
-            {}
-        )  # Cache for variable validation
+        self._substitution_cache: Dict[
+            int, tuple[str, list[str]]
+        ] = {}  # Cache for substitution results (key: hash, value: (content, warnings))
+        self._variable_validation_cache: Dict[str, bool] = {}  # Cache for variable validation
         self.logger = logging.getLogger(__name__)
 
         if self.config.verbose_logging:
-            self.logger.info(
-                f"TemplateProcessor initialized with config: {self.config}"
-            )
+            self.logger.info(f"TemplateProcessor initialized with config: {self.config}")
 
     def set_context(self, context: dict[str, str]) -> None:
         """Set variable substitution context with enhanced validation.
@@ -213,21 +199,15 @@ class TemplateProcessor:
 
             # Check variable length
             if len(var_name) > self.config.max_variable_length:
-                warning_messages.append(
-                    f"Variable name '{var_name}' exceeds maximum length"
-                )
+                warning_messages.append(f"Variable name '{var_name}' exceeds maximum length")
 
             # Check variable value length
             if len(var_value) > self.config.max_variable_length * 2:
-                warning_messages.append(
-                    f"Variable value '{var_value[:20]}...' is very long"
-                )
+                warning_messages.append(f"Variable value '{var_value[:20]}...' is very long")
 
             # Check for potentially dangerous values
             if "{{" in var_value or "}}" in var_value:
-                warning_messages.append(
-                    f"Variable '{var_name}' contains placeholder patterns"
-                )
+                warning_messages.append(f"Variable '{var_name}' contains placeholder patterns")
 
         # Check for common variables that should be present
         missing_common_vars = []
@@ -236,28 +216,20 @@ class TemplateProcessor:
                 missing_common_vars.append(common_var)
 
         if missing_common_vars and self.config.enable_substitution_warnings:
-            warning_messages.append(
-                f"Common variables missing: {', '.join(missing_common_vars[:3])}"
-            )
+            warning_messages.append(f"Common variables missing: {', '.join(missing_common_vars[:3])}")
 
         # Report validation results
         if validation_errors and not self.config.graceful_degradation:
-            raise ValueError(
-                f"Template variable validation failed: {validation_errors}"
-            )
+            raise ValueError(f"Template variable validation failed: {validation_errors}")
 
         if validation_errors and self.config.graceful_degradation:
-            self.logger.warning(
-                f"Template variable validation warnings: {validation_errors}"
-            )
+            self.logger.warning(f"Template variable validation warnings: {validation_errors}")
 
         if warning_messages and self.config.enable_substitution_warnings:
             self.logger.warning(f"Template variable warnings: {warning_messages}")
 
         if self.config.verbose_logging:
-            self.logger.debug(
-                f"Template variables validated: {len(context)} variables checked"
-            )
+            self.logger.debug(f"Template variables validated: {len(context)} variables checked")
 
     def get_enhanced_version_context(self) -> dict[str, str]:
         """
@@ -278,28 +250,16 @@ class TemplateProcessor:
 
             # Basic version information
             version_context["MOAI_VERSION"] = moai_version
-            version_context["MOAI_VERSION_SHORT"] = self._format_short_version(
-                moai_version
-            )
-            version_context["MOAI_VERSION_DISPLAY"] = self._format_display_version(
-                moai_version
-            )
+            version_context["MOAI_VERSION_SHORT"] = self._format_short_version(moai_version)
+            version_context["MOAI_VERSION_DISPLAY"] = self._format_display_version(moai_version)
 
             # Enhanced formatting options
-            version_context["MOAI_VERSION_TRIMMED"] = self._format_trimmed_version(
-                moai_version, max_length=10
-            )
-            version_context["MOAI_VERSION_SEMVER"] = self._format_semver_version(
-                moai_version
-            )
+            version_context["MOAI_VERSION_TRIMMED"] = self._format_trimmed_version(moai_version, max_length=10)
+            version_context["MOAI_VERSION_SEMVER"] = self._format_semver_version(moai_version)
 
             # Validation and source information
-            version_context["MOAI_VERSION_VALID"] = (
-                "true" if moai_version != "unknown" else "false"
-            )
-            version_context["MOAI_VERSION_SOURCE"] = self._get_version_source(
-                version_reader
-            )
+            version_context["MOAI_VERSION_VALID"] = "true" if moai_version != "unknown" else "false"
+            version_context["MOAI_VERSION_SOURCE"] = self._get_version_source(version_reader)
 
             # Performance metrics
             cache_age = version_reader.get_cache_age_seconds()
@@ -311,9 +271,7 @@ class TemplateProcessor:
             # Additional metadata
             if self.config.enable_version_validation:
                 is_valid = self._is_valid_version_format(moai_version)
-                version_context["MOAI_VERSION_FORMAT_VALID"] = (
-                    "true" if is_valid else "false"
-                )
+                version_context["MOAI_VERSION_FORMAT_VALID"] = "true" if is_valid else "false"
 
             if self.config.verbose_logging:
                 logger.debug(f"Enhanced version context generated: {version_context}")
@@ -323,21 +281,11 @@ class TemplateProcessor:
             # Use fallback version with comprehensive formatting
             fallback_version = self.config.version_fallback
             version_context["MOAI_VERSION"] = fallback_version
-            version_context["MOAI_VERSION_SHORT"] = self._format_short_version(
-                fallback_version
-            )
-            version_context["MOAI_VERSION_DISPLAY"] = self._format_display_version(
-                fallback_version
-            )
-            version_context["MOAI_VERSION_TRIMMED"] = self._format_trimmed_version(
-                fallback_version, max_length=10
-            )
-            version_context["MOAI_VERSION_SEMVER"] = self._format_semver_version(
-                fallback_version
-            )
-            version_context["MOAI_VERSION_VALID"] = (
-                "false" if fallback_version == "unknown" else "true"
-            )
+            version_context["MOAI_VERSION_SHORT"] = self._format_short_version(fallback_version)
+            version_context["MOAI_VERSION_DISPLAY"] = self._format_display_version(fallback_version)
+            version_context["MOAI_VERSION_TRIMMED"] = self._format_trimmed_version(fallback_version, max_length=10)
+            version_context["MOAI_VERSION_SEMVER"] = self._format_semver_version(fallback_version)
+            version_context["MOAI_VERSION_VALID"] = "false" if fallback_version == "unknown" else "true"
             version_context["MOAI_VERSION_SOURCE"] = "fallback_config"
             version_context["MOAI_VERSION_CACHE_AGE"] = "unavailable"
             version_context["MOAI_VERSION_FORMAT_VALID"] = "false"
@@ -495,9 +443,7 @@ class TemplateProcessor:
                 if self.config.validate_template_variables:
                     # Validate variable before substitution
                     if not self._is_valid_template_variable(key, value):
-                        warnings.append(
-                            f"Invalid variable {key} - skipped substitution"
-                        )
+                        warnings.append(f"Invalid variable {key} - skipped substitution")
                         continue
 
                 safe_value = self._sanitize_value(value)
@@ -519,17 +465,13 @@ class TemplateProcessor:
                     suggestion = self.COMMON_TEMPLATE_VARIABLES[var]
                     warning_parts.append(f"{{{{{var}}}}} → {suggestion}")
                 else:
-                    warning_parts.append(
-                        f"{{{{{var}}}}} → Unknown variable (check template)"
-                    )
+                    warning_parts.append(f"{{{{{var}}}}} → Unknown variable (check template)")
 
             warnings.append("Template variables not substituted:")
             warnings.extend(f"  • {part}" for part in warning_parts)
 
             if self.config.enable_substitution_warnings:
-                warnings.append(
-                    "💡 Run 'uv run moai-adk update' to fix template variables"
-                )
+                warnings.append("💡 Run 'uv run moai-adk update' to fix template variables")
 
         # Add performance information if verbose logging is enabled
         if self.config.verbose_logging:
@@ -660,7 +602,7 @@ class TemplateProcessor:
         Returns:
             Content with localized descriptions.
         """
-        import yaml
+        import yaml  # type: ignore[import-untyped]
 
         # Pattern to match YAML frontmatter
         frontmatter_pattern = r"^---\n(.*?)\n---"
@@ -715,9 +657,7 @@ class TemplateProcessor:
                 content, file_warnings = self._substitute_variables(content)
 
                 # Apply description localization for command/output-style files
-                if src.suffix == ".md" and (
-                    "commands/alfred" in str(src) or "output-styles/alfred" in str(src)
-                ):
+                if src.suffix == ".md" and ("commands/alfred" in str(src) or "output-styles/alfred" in str(src)):
                     lang = self.context.get("CONVERSATION_LANGUAGE", "en")
                     content = self._localize_yaml_description(content, lang)
 
@@ -860,6 +800,7 @@ class TemplateProcessor:
             "output-styles/moai",
             "agents/alfred",
             "agents/moai",
+            "skills",  # NEW: Complete replacement for skills folder
         ]
 
         # 1. Copy Alfred and Moai folders wholesale (backup before delete & overwrite)
@@ -906,7 +847,7 @@ class TemplateProcessor:
                 if not silent:
                     console.print(f"   ✅ .claude/{rel_subdir}/ copied")
 
-        # 2. Copy other files/folders individually (smart merge for settings.json)
+        # 2. Copy other files/folders individually (smart merge for settings.json and config.json)
         all_warnings = []
         for item in src.iterdir():
             rel_path = item.relative_to(src)
@@ -932,9 +873,12 @@ class TemplateProcessor:
                         dst_item.write_text(content, encoding="utf-8")
                         all_warnings.extend(file_warnings)
                     if not silent:
-                        console.print(
-                            "   🔄 settings.json merged (Hook paths configured for your OS)"
-                        )
+                        console.print("   🔄 settings.json merged (Hook paths configured for your OS)")
+                # Smart merge for config.json
+                elif item.name == "config.json":
+                    self._merge_config_json(item, dst_item)
+                    if not silent:
+                        console.print("   🔄 config.json merged (user preferences preserved)")
                 else:
                     # FORCE OVERWRITE: Always copy other files (no skip)
                     warnings = self._copy_file_with_substitution(item, dst_item)
@@ -1017,12 +961,10 @@ class TemplateProcessor:
             self._copy_dir_with_substitution(src, dst)
 
         if not silent:
-            console.print(
-                "   🔄 .github/ merged (user workflows preserved, variables substituted)"
-            )
+            console.print("   🔄 .github/ merged (user workflows preserved, variables substituted)")
 
     def _copy_claude_md(self, silent: bool = False) -> None:
-        """Copy CLAUDE.md with smart merge (preserves \"## Project Information\" section)."""
+        """Copy CLAUDE.md with complete replacement (no merge)."""
         src = self.template_root / "CLAUDE.md"
         dst = self.target_path / "CLAUDE.md"
 
@@ -1031,27 +973,11 @@ class TemplateProcessor:
                 console.print("⚠️ CLAUDE.md template not found")
             return
 
-        # Smart merge: preserve existing "## Project Information" section
-        if dst.exists():
-            self._merge_claude_md(src, dst)
-            # Substitute variables in the merged content
-            if self.context:
-                content = dst.read_text(encoding="utf-8")
-                content, warnings = self._substitute_variables(content)
-                dst.write_text(content, encoding="utf-8")
-                if warnings and not silent:
-                    console.print("[yellow]⚠️ Template warnings:[/yellow]")
-                    for warning in set(warnings):
-                        console.print(f"   {warning}")
-            if not silent:
-                console.print(
-                    "   🔄 CLAUDE.md merged (project information preserved, variables substituted)"
-                )
-        else:
-            # First time: just copy
-            self._copy_file_with_substitution(src, dst)
-            if not silent:
-                console.print("   ✅ CLAUDE.md created")
+        # Simple copy with substitution (no merge)
+        self._copy_file_with_substitution(src, dst)
+
+        if not silent:
+            console.print("   ✅ CLAUDE.md replaced (use CLAUDE.local.md for personal instructions)")
 
     def _merge_claude_md(self, src: Path, dst: Path) -> None:
         """Delegate the smart merge for CLAUDE.md.
@@ -1080,15 +1006,119 @@ class TemplateProcessor:
         """
         # Find the latest backup for user settings extraction
         backup_path = None
-        if self.backup.backup_dir.exists():
-            backups = sorted(self.backup.backup_dir.iterdir(), reverse=True)
-            if backups:
-                backup_settings = backups[0] / ".claude" / "settings.json"
-                if backup_settings.exists():
-                    backup_path = backup_settings
+        latest_backup = self.backup.get_latest_backup()
+        if latest_backup:
+            backup_settings = latest_backup / ".claude" / "settings.json"
+            if backup_settings.exists():
+                backup_path = backup_settings
 
         self.merger.merge_settings_json(src, dst, backup_path)
 
+    def _merge_config_json(self, src: Path, dst: Path) -> None:
+        """Smart merge for config.json using LanguageConfigResolver priority system.
+
+        Args:
+            src: Template config.json.
+            dst: Project config.json.
+        """
+        import json
+
+        # Load template config
+        try:
+            template_config = json.loads(src.read_text(encoding="utf-8"))
+        except (json.JSONDecodeError, FileNotFoundError) as e:
+            console.print(f"⚠️ Warning: Could not read template config.json: {e}")
+            return
+
+        # Find latest backup config.json
+        latest_backup = self.backup.get_latest_backup()
+        if latest_backup:
+            backup_config_path = latest_backup / ".moai" / "config" / "config.json"
+            if backup_config_path.exists():
+                try:
+                    json.loads(backup_config_path.read_text(encoding="utf-8"))
+                except json.JSONDecodeError as e:
+                    console.print(f"⚠️ Warning: Could not read backup config.json: {e}")
+
+        # Load existing project config.json
+        existing_config = {}
+        if dst.exists():
+            try:
+                existing_config = json.loads(dst.read_text(encoding="utf-8"))
+            except json.JSONDecodeError as e:
+                console.print(f"⚠️ Warning: Could not read existing config.json: {e}")
+
+        # Merge with priority system: Environment > Existing User > Template
+        # We'll use LanguageConfigResolver to handle this properly
+        try:
+            # Import LanguageConfigResolver for priority-based merging
+            from moai_adk.core.language_config_resolver import LanguageConfigResolver
+
+            # Create temporary resolver to handle merging
+            temp_project_path = self.target_path / ".moai" / "config"
+            temp_project_path.mkdir(parents=True, exist_ok=True)
+
+            # Start with template config as base
+            merged_config = template_config.copy()
+
+            # Apply existing user config (higher priority than template)
+            for key, value in existing_config.items():
+                if key not in ["config_source"]:  # Skip metadata
+                    if key in merged_config and isinstance(merged_config[key], dict) and isinstance(value, dict):
+                        # Deep merge for nested objects
+                        merged_config[key].update(value)
+                    else:
+                        merged_config[key] = value
+
+            # Apply environment variables (highest priority)
+            import os
+
+            env_mappings = {
+                "MOAI_USER_NAME": ("user", "name"),
+                "MOAI_CONVERSATION_LANG": ("language", "conversation_language"),
+                "MOAI_AGENT_PROMPT_LANG": ("language", "agent_prompt_language"),
+                "MOAI_CONVERSATION_LANG_NAME": (
+                    "language",
+                    "conversation_language_name",
+                ),
+                "MOAI_GIT_COMMIT_MESSAGES_LANG": ("language", "git_commit_messages"),
+                "MOAI_CODE_COMMENTS_LANG": ("language", "code_comments"),
+                "MOAI_DOCUMENTATION_LANG": ("language", "documentation"),
+                "MOAI_ERROR_MESSAGES_LANG": ("language", "error_messages"),
+            }
+
+            for env_var, (section, key) in env_mappings.items():
+                env_value = os.getenv(env_var)
+                if env_value:
+                    if section not in merged_config:
+                        merged_config[section] = {}
+                    merged_config[section][key] = env_value
+
+            # Ensure consistency
+            resolver = LanguageConfigResolver(str(self.target_path))
+            merged_config = resolver._ensure_consistency(merged_config)
+
+            # Write merged config
+            dst.write_text(
+                json.dumps(merged_config, indent=2, ensure_ascii=False) + "\n",
+                encoding="utf-8",
+            )
+
+        except ImportError:
+            # Fallback: simple merge without LanguageConfigResolver
+            merged_config = template_config.copy()
+
+            # Apply existing config
+            for key, value in existing_config.items():
+                if key not in ["config_source"]:
+                    merged_config[key] = value
+
+            dst.write_text(
+                json.dumps(merged_config, indent=2, ensure_ascii=False) + "\n",
+                encoding="utf-8",
+            )
+            console.print("   ⚠️ Warning: Using simple merge (LanguageConfigResolver not available)")
+
     def _copy_gitignore(self, silent: bool = False) -> None:
         """.gitignore copy (optional)."""
         src = self.template_root / ".gitignore"
